;;*****************************************************************************
;;*****************************************************************************
;;  FILENAME: ADCINC_1INT.asm
;;  Version: 1.1, Updated on 2006/05/03 at 11:26:54
;;
;;  DESCRIPTION: Assembler interrupt service routine for the ADCINC
;;               A/D Converter User Module. This code works for both the
;;               first and second-order modulator topologies.
;;-----------------------------------------------------------------------------
;;  Copyright (c) Cypress MicroSystems 2000-2003. All Rights Reserved.
;;*****************************************************************************
;;*****************************************************************************

include "m8c.inc"
include "memory.inc"
include "ADCINC_1.inc"


;-----------------------------------------------
;  Global Symbols
;-----------------------------------------------

export _ADCINC_1_ADConversion_ISR

export _ADCINC_1_iResult
export  ADCINC_1_iResult
export _ADCINC_1_fStatus
export  ADCINC_1_fStatus
export _ADCINC_1_bState
export  ADCINC_1_bState
export _ADCINC_1_fMode
export  ADCINC_1_fMode
export _ADCINC_1_bNumSamples
export  ADCINC_1_bNumSamples

;-----------------------------------------------
; Variable Allocation
;-----------------------------------------------
AREA InterruptRAM(RAM,REL)
 ADCINC_1_iResult:
_ADCINC_1_iResult:                         BLK  2 ;Calculated answer
  iTemp:                                   BLK  2 ;internal temp storage
 ADCINC_1_fStatus:
_ADCINC_1_fStatus:                         BLK  1 ;ADC Status
 ADCINC_1_bState:
_ADCINC_1_bState:                          BLK  1 ;State value of ADC count
 ADCINC_1_fMode:
_ADCINC_1_fMode:                           BLK  1 ;Integrate and reset mode.
 ADCINC_1_bNumSamples:
_ADCINC_1_bNumSamples:                     BLK  1 ;Number of samples to take.

;-----------------------------------------------
;  EQUATES
;-----------------------------------------------

;@PSoC_UserCode_INIT@ (Do not change this line.)
;---------------------------------------------------
; Insert your custom declarations below this banner
;---------------------------------------------------

;------------------------
;  Constant Definitions
;------------------------


;------------------------
; Variable Allocation
;------------------------


;---------------------------------------------------
; Insert your custom declarations above this banner
;---------------------------------------------------
;@PSoC_UserCode_END@ (Do not change this line.)


AREA UserModules (ROM, REL)

;-----------------------------------------------------------------------------
;  FUNCTION NAME: _ADCINC_1_ADConversion_ISR
;
;  DESCRIPTION: Perform final filter operations to produce output samples.
;
;-----------------------------------------------------------------------------
;
;    The decimation rate is established by the PWM interrupt. Four timer
;    clocks elapse for each modulator output (decimator input) since the
;    phi1/phi2 generator divides by 4. This means the timer period and thus
;    it's interrupt must equal 4 times the actual decimation rate.  The
;    decimator is ru  for 2^(#bits-6).
;
_ADCINC_1_ADConversion_ISR:
    dec  [ADCINC_1_bState]
if1:
    jc endif1 ; no underflow
    reti
endif1:
    cmp [ADCINC_1_fMode],0
if2: 
    jnz endif2  ;leaving reset mode
    push A                            ;read decimator
    mov  A, reg[DEC_DL]
    mov  [iTemp + LowByte],A
    mov  A, reg[DEC_DH]
    mov  [iTemp + HighByte], A
    pop A
    mov [ADCINC_1_fMode],1
    mov [ADCINC_1_bState],((1<<(ADCINC_1_bNUMBITS- 6))-1)
    reti
endif2:
    ;This code runs at end of integrate
    ADCINC_1_RESET_INTEGRATOR_M
    push A
    mov  A, reg[DEC_DL]
    sub  A,[iTemp + LowByte]
    mov  [iTemp +LowByte],A
    mov  A, reg[DEC_DH]
    sbb  A,[iTemp + HighByte]
    asr  A
    rrc  [iTemp + LowByte]

       ;Covert to Unipolar
IF  ADCINC_1_9_OR_MORE_BITS
    add  A, (1<<(ADCINC_1_bNUMBITS - 9))
ELSE
    add [iTemp + LowByte], (1<<(ADCINC_1_bNUMBITS - 1)) ;work on lower Byte
    adc A,0 
ENDIF
       ;check for overflow
IF     ADCINC_1_8_OR_MORE_BITS
    cmp A,(1<<(ADCINC_1_bNUMBITS - 8))
if3: 
    jnz endif3 ;overflow
    dec A
    mov [iTemp + LowByte],ffh
endif3:
ELSE
    cmp [iTemp + LowByte],(1<<(ADCINC_1_bNUMBITS))
if4: 
    jnz endif4 ;overflow
    dec [iTemp + LowByte]
endif4:
ENDIF
IF ADCINC_1_SIGNED_DATA
IF ADCINC_1_9_OR_MORE_BITS
    sub A,(1<<(ADCINC_1_bNUMBITS - 9))
ELSE
    sub [iTemp +LowByte],(1<<(ADCINC_1_bNUMBITS - 1))
    sbb A,0
ENDIF
ENDIF
    mov  [ADCINC_1_iResult + LowByte],[iTemp +LowByte]
    mov  [ADCINC_1_iResult + HighByte],A
    mov  [ADCINC_1_fStatus],1
ConversionReady:
    ;@PSoC_UserCode_BODY@ (Do not change this line.)
    ;---------------------------------------------------
    ; Insert your custom code below this banner
    ;---------------------------------------------------
    mov [ADCINC_1_fStatus],0			;restore status ("data is not ready")
m0: cmp [ADCINC_1_bNumSamples],5
    jnz m1
    	mov [No+0],[ADCINC_1_iResult+1]	;LowByte
    	mov [No+1],[ADCINC_1_iResult+0]	;HighByte
		M8C_SetBank1
		and reg[ABF_CR0],0b10111111		;set analog input muxes
		M8C_SetBank0
		jmp m_end
m1:	cmp [ADCINC_1_bNumSamples],4   
    jnz m2
		;Nr=ADC-No 	
		mov A,[ADCINC_1_iResult+1]	;LowByte
		sub A,[No+0]
		mov [Nr+0],A
		mov A,[ADCINC_1_iResult+0]	;HighByte
		sbb A,[No+1]
		mov [Nr+1],A
		mov reg[AMX_IN],0b01010000		;set analog input muxes P0[2] P0[3] (Col3 Col2)
		jmp m_end
m2:	cmp [ADCINC_1_bNumSamples],3   
    jnz m3
		;N1=No-ADC	
		mov A,[No+0]
		sub A,[ADCINC_1_iResult+1]	;LowByte
		mov [N1+0],A
		mov A,[No+1]
		sbb A,[ADCINC_1_iResult+0]	;HighByte
		mov [N1+1],A
		mov reg[AMX_IN],0b01000000		;set analog input muxes P0[2] P0[1] (Col3 Col2)
		jmp m_end
m3:	cmp [ADCINC_1_bNumSamples],2   
    jnz m4
		;N2=ADC-No 	
		mov A,[ADCINC_1_iResult+1]	;LowByte
		sub A,[No+0]
		mov [N2+0],A
		mov A,[ADCINC_1_iResult+0]	;HighByte
		sbb A,[No+1]
		mov [N2+1],A
		mov reg[AMX_IN],0b00000000		;set analog input muxes P0[0] P0[1] (Col3 Col2)
		jmp m_end
m4:	cmp [ADCINC_1_bNumSamples],1   
    jnz m_end
	    mov [ADCINC_1_bNumSamples],6    
		;N3=No-ADC	
		mov A,[No+0]	;N3=No-N3
		sub A,[ADCINC_1_iResult+1]	;LowByte
		mov [N3+0],A
		mov A,[No+1]
		sbb A,[ADCINC_1_iResult+0]	;HighByte
		mov [N3+1],A
		mov reg[AMX_IN],0b10010000		;set analog input muxes P0[4] P0[3] (Col3 Col2)
		M8C_SetBank1
		or  reg[ABF_CR0],0b01000000		;set analog input muxes
		M8C_SetBank0
		mov [ADCINC_1_fStatus],1		;set status ("data is ready")
		jmp m_end
m_end:
    ;---------------------------------------------------
    ; Insert your custom code above this banner
    ;---------------------------------------------------
    ;@PSoC_UserCode_END@ (Do not change this line.)
    pop A
    cmp [ADCINC_1_bNumSamples],0
if5: 
    jnz endif5 ; Number of samples is zero
    mov [ADCINC_1_fMode],0
    mov [ADCINC_1_bState],0
    ADCINC_1_ENABLE_INTEGRATOR_M
    reti       
endif5:
    dec [ADCINC_1_bNumSamples]
if6:
    jz endif6  ; count not zero
    mov [ADCINC_1_fMode],0
    mov [ADCINC_1_bState],0
    ADCINC_1_ENABLE_INTEGRATOR_M
    reti       
endif6:
    ;All samples done
    ADCINC_1_STOPADC_M
 reti 
; end of file ADCINC_1INT.asm
